pub enum PropertyClass {
Effective(Option<String>),
DirectlyAttachedUncomposed,
DirectlyAttachedComposed,
}Expand description
The selection of properties for a service or instance.
Services always return directly attached properties; these options only apply to service instances.
Variants
Effective(Option<String>)
Effective properties, relative to an optional snapshot. For instances: The composed view of the snapshot with all non-persistent properties.
This is equivalent to svcprop with no arguments,
or svcprop -s <snapshot> if a string is supplied.
DirectlyAttachedUncomposed
Directly attached properties, with no composition nor snapshots.
This is equivalent to svcprop -C.
DirectlyAttachedComposed
Directly attached properties, composed with the directly attached properties of the service.
This is equivalent to svcprop -c.